@@ -14,6 +14,7 @@
 # from threading import Thread
 import traceback
 import shutil
+import time
 import os
 from pathlib import Path
 import logging
@@ -429,8 +430,18 @@ def index_files(start_path, extension_array=None, ignore_array=None, recursive=T
             break
     return file_array
 
+def persistent_delete(file_path,attempt_limit=100):
+    success = False
+    attempt_count = 0
+    while success is False:
+        attempt_count += 1
+        if attempt_limit == attempt_count:
+            return False
+        success = delete(file_path)
+        time.sleep(1)
+    return success
 
-def delete(file_path, ftp=None):
+def delete(file_path, ftp=None,persistent=True):
     '''
         Deletes a directory from the local machine or FTP server.
 
@@ -457,19 +468,26 @@ def delete(file_path, ftp=None):
         `version`: 1.0
         `method_name`: delete
     '''
-    success = False
-    if ftp is not None:
-        success = delete_ftp(file_path, ftp)
-    else:
-        try:
-            shutil.rmtree(file_path)
-            success = True
-        except OSError as error:
-            logger.warning("Failed to delete local directory: %s", file_path)
-            logger.warning("Error: %s : %s", file_path, error.strerror)
-            success = False
-            # print("Error: %s : %s" % (file_path, error.strerror))
-    return success
+    attempt_limit = 100
+    if persistent is False:
+        attempt_limit = 1
+        
+    for idx in range(attempt_limit):
+        # success = False
+        if ftp is not None:
+            success = delete_ftp(file_path, ftp)
+        else:
+            try:
+                shutil.rmtree(file_path)
+                success = True
+                return True
+            except OSError as error:
+                if persistent is False:
+                    logger.warning("Failed to delete local directory: %s", file_path)
+                    logger.warning("Error: %s : %s", file_path, error.strerror)
+                    # success = False
+                # print("Error: %s : %s" % (file_path, error.strerror))
+        return success
 
 
 def delete_ftp(file_path, ftp):
