@@ -843,6 +843,37 @@ def get_data(file_path, **kwargs):
         logger.warning("Failed to find the file: %s", file_path)
         return None
 
+def get_drive(file_path,strip_colon=True):
+    '''
+        Get the drive letter from the file path.
+
+        ----------
+
+        Arguments
+        -------------------------
+        `file_path` {string}
+            The file path to parse.
+        [`strip_colon`=True] {boolean}
+            If False the colon is not removed from the drive letter.
+
+        Return {string}
+        ----------------------
+        The drive letter of the path.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 04\03\2022 12:06:31
+        `memberOf`: file
+        `version`: 1.0
+        `method_name`: get_drive
+        # @xxx [04\03\2022 12:09:25]: documentation for get_drive
+    '''
+
+    drive_tail = os.path.splitdrive(file_path)
+    if strip_colon is True:
+        return drive_tail[0].replace(":","")
+    return drive_tail[0]
 
 def get_modified_time(file_path, ftp=None):
     '''
